#
# spec file for package uhubctl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           uhubctl
Version:        2.6.0
Release:        1.2
Summary:        USB hub per-port power control
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://github.com/mvp/uhubctl
Source:         https://github.com/mvp/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libusb-1.0)

%description
uhubctl is utility to control USB power per-port on smart USB hubs.
Smart hub is defined as one that implements per-port power switching.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
make %{?_smp_mflags}

%install
%make_install

%files
%license COPYING LICENSE
%doc README.md
%{_sbindir}/uhubctl

%changelog
* Mon Sep  9 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.0
  * Added support for Raspberry Pi 5 .
  * Fixed bug for big-endian platforms.
  * Fixed sysfs path bug for Linux kernel 6.x or higher.
  * Added flash (inverted cycle) option - turn power on then off.
  * Improved Linux detection.
  * Added more devices to supported table.
* Fri Nov  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.0
  * Added support for Linux sysfs based power switching provided
    in Linux kernel 6.0+ - it allows to solve reliability issues
    when turning power off on Linux.
  * Added option --nodesc to skip querying device string
    descriptors (necessary for some buggy devices which otherwise
    would completely freeze).
  * New simpler way to configure udev rules on Linux (one rule
    works for any USB hub).
  * Even more supported devices.
* Sun Feb 14 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4.0
  * Support for toggle action (turn power on or off opposite to
    current power state).
  * More sane error reporting when we enumerate devices which
    lack permissions.
  * Allow pkg-config override to make some build systems (e.g.
    chromium OS) happier.
  * Even more supported devices.
* Mon Dec 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
  * Much improved USB3 support, in particular for RPi 4B and
    M1 Macs
  * Allow forced operation on unsupported hubs - not likely to
    work though
  * More supported devices
* Sat May 23 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.2.0
  * Added support for Raspberry Pi 4B
  * Added many more devices to supported table
* Tue Sep  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 2.1.0:
  * Add explicit workaround for USB device not removed after port
    power down on Linux
  * Implemented reading ContainerID from BOS descriptor to detect
    USB2/3 dual devices
  * Support fractional seconds for delay
  * Improve USB2/3 duality handling
  * Add support for comma separated list of ranges to port list parser
  * Improve USB3 support
* Mon Jun 18 2018 mardnh@gmx.de
- Update to version 2.0.0+git20180615.1709413:
  * j5create JUH470 only works in USB2 mode
  * Add D-Link DUB H7 rev D1 (black) as supported device
  * Add Renesas uPD720202 PCIe USB 3.0 host controller as supported device
  * Add Raspberry Pi Model 3 B+ as supported device
  * Add columns for port count and USB version into device table
  * Code formatting cleanups
  * Fixed displaying duplicate hubs in status output
  * Add Moxa Uport-407 as supported device
  * Remove mention of building libusb 1.0.22 from head
  * move action to outer loop and hub to inner loop (fixes #86)
- Run spec-cleaner
* Tue May 30 2017 ptesarik@suse.com
- Update to version 0+git20170520.e537110:
  * Bump copyright year
  * Add AmazonBasics 7 port USB 3.0 hub as supported device
  * Add Asus Z87-PLUS as supported device
  * Add Rosewill RHUB-210 as supported device
  * Add support for FreeBSD and MacPorts on Mac
  * Add information about release and EOL years for supported hubs
  * add option to reset hub after operation
  * Add Sunix SHB4200MA as compatible device
  * fix docs for -R (from #30)
* Tue May 30 2017 ptesarik@suse.com
- initial commit.
